<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://dreamstyle.photos
 * @since      1.0.0
 *
 * @package    Wp_csp
 * @subpackage Wp_csp/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 */
class Wp_Csp_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Csp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Csp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_register_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wp_csp-admin.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Csp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Csp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// Enqueue WP media API JS.
		wp_enqueue_media();

		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wp_csp-admin.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name );

	}

	/**
	 * Registers required custom post types.
	 *
	 * @since   1.0.0
	 */
	public function register_cpts() {

		$labels = array(
			'name'                  => _x( 'Click&Sell Photos', 'Post Type General Name', 'wp_csp' ),
			'singular_name'         => _x( 'CSP', 'Post Type Singular Name', 'wp_csp' ),
			'menu_name'             => __( 'Click&Sell Photos', 'wp_csp' ),
			'name_admin_bar'        => __( 'CSP', 'wp_csp' ),
			'archives'              => __( 'Item Archives', 'wp_csp' ),
			'attributes'            => __( 'Item Attributes', 'wp_csp' ),
			'parent_item_colon'     => __( 'Parent Item:', 'wp_csp' ),
			'all_items'             => __( 'All client albums', 'wp_csp' ),
			'add_new_item'          => __( 'Add New Item', 'wp_csp' ),
			'add_new'               => __( 'New client album', 'wp_csp' ),
			'new_item'              => __( 'New Item', 'wp_csp' ),
			'edit_item'             => __( 'Edit Item', 'wp_csp' ),
			'update_item'           => __( 'Update Item', 'wp_csp' ),
			'view_item'             => __( 'View Item', 'wp_csp' ),
			'view_items'            => __( 'View Items', 'wp_csp' ),
			'search_items'          => __( 'Search Item', 'wp_csp' ),
			'not_found'             => __( 'Not found', 'wp_csp' ),
			'not_found_in_trash'    => __( 'Not found in Trash', 'wp_csp' ),
			'featured_image'        => __( 'Featured Image', 'wp_csp' ),
			'set_featured_image'    => __( 'Set featured image', 'wp_csp' ),
			'remove_featured_image' => __( 'Remove featured image', 'wp_csp' ),
			'use_featured_image'    => __( 'Use as featured image', 'wp_csp' ),
			'insert_into_item'      => __( 'Insert into item', 'wp_csp' ),
			'uploaded_to_this_item' => __( 'Uploaded to this item', 'wp_csp' ),
			'items_list'            => __( 'Items list', 'wp_csp' ),
			'items_list_navigation' => __( 'Items list navigation', 'wp_csp' ),
			'filter_items_list'     => __( 'Filter items list', 'wp_csp' ),
		);

		$args = array(
			'label'               => __( 'CSP', 'wp_csp' ),
			'labels'              => $labels,
			'supports'            => array( 'title' ),
			'taxonomies'          => array(),
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'menu_position'       => 4,
			'menu_icon'           => 'dashicons-camera',
			'show_in_admin_bar'   => true,
			'show_in_nav_menus'   => true,
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => false,
			'publicly_queryable'  => true,
			'capability_type'     => 'page',
		);

		// Register main CPT.
		register_post_type( CSP_CPT_NAME, $args );

	}

	/**
	 * Registers woo image size.
	 *
	 * @since   1.0.0
	 */
	public function register_image_size() {
		add_image_size( CSP_PLUGIN_PREFIX . '-size', 350 );

	}

	/**
	 * Adds meta box in CPTs.
	 *
	 * @since   1.0.0
	 */
	public function add_meta_boxes() {

		// Add item editor meta box to the album.
		add_meta_box(
			CSP_PLUGIN_PREFIX . '_editor', // 'id' attribute of the meta box.
			__( 'Click&Sell Photos - Create client album', 'wp_csp' ),
			function ( $post ) {
				$output = Wp_Csp_Admin_Display::get_album_editor_html( $post );
				$arr    = array(
					'div'      => array(
						'class' => array(),
						'id'    => array(),
						'style' => array(),
					),
					'img'      => array(
						'class' => array(),
						'src'   => array(),
					),
					'input'    => array(
						'class'   => array(),
						'type'    => array(),
						'value'   => array(),
						'data-id' => array(),
						'id'      => array(),
						'name'    => array(),
					),
					'textarea' => array(
						'class' => array(),
						'rows'  => array(),
						'value' => array(),
						'cols'  => array(),
						'id'    => array(),
						'name'  => array(),
					),
					'label'    => array(
						'for' => array(),
					),
					'p'        => array(
						'class' => array(),
						'style' => array(),
					),
					'table'    => array(
						'width'  => array(),
						'border' => array(),
					),
					'tbody'    => array(),
					'tr'       => array(
						'id'    => array(),
						'style' => array(),
					),
					'td'       => array(
						'colspan' => array(),
						'class'   => array(),
					),
				);
				echo wp_kses( $output, $arr );

			},
			CSP_CPT_NAME,
			'advanced',
			'high'
		);

	}

	/**
	 * Stores post meta fields in DB.
	 *
	 * @since   1.0.0
	 *
	 * @param   int $post_id        Current post ID.
	 */
	public function save_post_meta_fields( $post_id ) {

		// verify nonce.
		if ( ! isset( $_POST[ CSP_SAVE_META_BOX_NONCE ] ) || ! wp_verify_nonce( sanitize_key( $_POST[ CSP_SAVE_META_BOX_NONCE ] ), CSP_SAVE_META_BOX_ACTION_NAME ) ) {
			return 'nonce not verified';
		}

		// check autosave.
		if ( wp_is_post_autosave( $post_id ) ) {
			return 'autosave';
		}

		// check post revision.
		if ( wp_is_post_revision( $post_id ) ) {
			return 'revision';
		}

		// check permissions.
		if ( isset( $_POST['post_type'] ) && CSP_CPT_NAME == $_POST['post_type'] ) {

			if ( ! current_user_can( 'edit_page', $post_id ) ) {
				return 'cannot edit page';
			}
		} elseif ( ! current_user_can( 'edit_post', $post_id ) ) {
			return 'cannot edit post';
		}

		/* Validate meta fields and store there values in post meta. */

		// Client album secret code.
		if ( isset( $_POST[ CSP_ALBUM_SECRET_CODE_META_KEY ] ) ) {
			update_post_meta( $post_id, CSP_ALBUM_SECRET_CODE_META_KEY, sanitize_key( $_POST[ CSP_ALBUM_SECRET_CODE_META_KEY ] ) );
		}

		// Client album images.
		if ( isset( $_POST[ CSP_ALBUM_IMAGES_META_KEY ] ) ) {
			$post            = $_POST;
			$selected_images = (array) json_decode( wp_unslash( $post[ CSP_ALBUM_IMAGES_META_KEY ] ) );
			if ( count( $selected_images ) > 10 ) {
				$selected_images = array_slice( $selected_images, 0, 10 );
			}
			update_post_meta( $post_id, CSP_ALBUM_IMAGES_META_KEY, $selected_images );

			$this->save_selected_album_images( $selected_images, $post_id );

		}

		// No of images to select.
		if ( isset( $_POST[ CSP_NO_OF_IMAGE_TO_SELECT_META_KEY ] ) ) {
			update_post_meta( $post_id, CSP_NO_OF_IMAGE_TO_SELECT_META_KEY, sanitize_key( $_POST[ CSP_NO_OF_IMAGE_TO_SELECT_META_KEY ] ) );
		}

		// Pricing per album chekcbox.
		if ( empty( $_POST[ CSP_PRICING_PER_ALBUM_META_KEY ] ) ) {
			update_post_meta( $post_id, CSP_PRICING_PER_ALBUM_META_KEY, 0 );
		} else {
			update_post_meta( $post_id, CSP_PRICING_PER_ALBUM_META_KEY, 1 );
		}

		// Album hint text.
		if ( isset( $_POST[ CSP_ALBUM_HINT_TEXT ] ) ) {
			$post = $_POST;
			update_post_meta( $post_id, CSP_ALBUM_HINT_TEXT, sanitize_text_field( $post[ CSP_ALBUM_HINT_TEXT ] ) );
		}

	}

	/**
	 * Create new folder and save selected album images
	 *
	 * @param   array $files        Files.
	 * @param   int   $post_id        Current post ID.
	 */
	public function save_selected_album_images( $files, $post_id ) {
		$upload_path = wp_upload_dir();
		$uploads_dir = trailingslashit( $upload_path['basedir'] ) . CSP_ALBUM_IMAGES_FOLDER;
		wp_mkdir_p( $uploads_dir );

		// delete the files.
		$current_imgs = get_post_meta( $post_id, CSP_ALBUM_IMAGES_META_KEY_RENAMED )[0];
		if ( $current_imgs ) {
			foreach ( $current_imgs as $img ) {
				@unlink( $uploads_dir . '/' . $img );
			}
		}

		if ( ! empty( $files ) ) {
			$new_images = array();
			foreach ( $files as $key => $val ) {
				$current_img   = $upload_path['basedir'] . '/' . image_get_intermediate_size( $key, CSP_PLUGIN_PREFIX . '-size' )['path'];
				$info          = pathinfo( $current_img );
				$ext           = empty( $info['extension'] ) ? '' : '.' . $info['extension'];
				$new_file_name = uniqid() . $ext;

				$new_img = $uploads_dir . '/' . $new_file_name;
				// copy.
				copy( $current_img, $new_img );

				$new_images[ $key ] = $new_file_name;
			}
			update_post_meta( $post_id, CSP_ALBUM_IMAGES_META_KEY_RENAMED, $new_images );
		}

	}

	/**
	 * Remove custom post type submenu.
	 */
	public function remove_custom_post_type_submenu() {
		global $submenu;
		unset( $submenu[ 'edit.php?post_type=' . CSP_PLUGIN_NAME ][10] );
	}

	/**
	 * Remove add new button
	 */
	public function remove_add_new_button() {
		global $pagenow;
		global $post;
		if ( 'edit.php' == $pagenow && isset( $_GET['post_type'] ) && CSP_PLUGIN_NAME == $_GET['post_type'] ) {
			global $wpdb;
			$post_count = 0;
			$post_count = $wpdb->get_var( "SELECT COUNT(*) FROM $wpdb->posts WHERE post_type = 'wp_csp' AND post_status in ('publish', 'draft', 'trash', 'pending')" );
			if ( $post_count >= 1 ) {
				echo '<style>.page-title-action { display: none; }</style>';
			}
		} elseif ( 'post.php' == $pagenow && CSP_PLUGIN_NAME == $post->post_type ) {
			echo '<style>.page-title-action { display: none; }</style>';
		}
	}

	/**
	 * Add Notification
	 */
	public function add_notification_to_admin_page() {
		$screen = get_current_screen();

		if ( $screen && ( 'dashboard' === $screen->id || CSP_PLUGIN_NAME === $screen->post_type ) ) {
			echo '<div class="notice notice-success is-dismissible">
			<h3>Click&amp;Sell Photos</h3>
			<p> 
				' . wp_kses(
				__( 'Do you dream of selling your stunning photos easily using WooCommerce? Your dream is about to come true! With our WordPress plugin and the photo-code you give to your customers, selling your photos will be easier than ever.<br><br><b>Why wait?</b> Take this opportunity and purchase the full version today.<b>Put an end to restrictions and unleash your full potential!</b><br><br>- <b>Create unlimited user albums with one photo code</b> <br>- <b>No more limit of 10 photos per album</b><br><br><b>Your success, our technology. Together unbeatable.</b>', 'wp_csp' ),
				array(
					'br' => array(),
					'b'  => array(),
				)
			) . '📸💰🌟
			</p>
        	<a href="' . esc_url( CSP_PLUGIN_GUIDE_URL ) . '" class="csp_custom_button csp_custom_button_green" target="_blank">' . esc_html__( 'Guide > How do I start with the Click&Sell Photos?', 'wp_csp' ) . '</a>
			<a href="' . esc_url( CSP_PLUGIN_BUY_URL ) . '" class="csp_custom_button" target="_blank">' . esc_html__( 'Buy the full version now!', 'wp_csp' ) . '</a>
		</div>';
		}
	}

}
