<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://dreamstyle.photos
 * @since      1.0.0
 *
 * @package    Wp_csp
 * @subpackage Wp_csp/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Wp_csp
 * @subpackage Wp_csp/includes
 */
class Wp_Csp {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @var      Wp_Csp_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Instance of plugin's public class.
	 *
	 * @since    1.0.0
	 * @var      object $plugin_public Instance of plugin's public class.
	 */
	protected $plugin_public;

	/**
	 * Instance of plugin's admin class.
	 *
	 * @since    1.0.0
	 * @var      object $plugin_admin Instance of plugin's admin class.
	 */
	protected $plugin_admin;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'WP_CSP_VERSION' ) ) {
			$this->version = WP_CSP_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'wp_csp';

		$this->load_dependencies();
		$this->inject_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_shortcodes();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - wp-csp_Loader. Orchestrates the hooks of the plugin.
	 * - wp-csp_i18n. Defines internationalization functionality.
	 * - wp-csp_Admin. Defines all hooks for the admin area.
	 * - wp-csp_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wp-csp-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wp-csp-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-wp-csp-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-wp-csp-public.php';

		/**
		 * The class responsible for defining all the HTMLs of the admin side.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/class-wp-csp-admin-display.php';

		$this->loader = new Wp_Csp_Loader();

	}

	/**
	 * Creates all the dependent objects.
	 *
	 * @since    1.0.0
	 */
	private function inject_dependencies() {

		// Plugin public object.
		$this->plugin_public = new Wp_Csp_Public( $this->get_plugin_name(), $this->get_version() );

		// Plugin admin object.
		$this->plugin_admin = new Wp_Csp_Admin( $this->get_plugin_name(), $this->get_version() );
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Wp_Csp_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 */
	private function set_locale() {

		$plugin_i18n = new Wp_Csp_I18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 */
	private function define_admin_hooks() {

		$this->loader->add_action( 'admin_enqueue_scripts', $this->plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $this->plugin_admin, 'enqueue_scripts' );

		// Action to add meta boxes in CPTs.
		$this->loader->add_action( 'add_meta_boxes', $this->plugin_admin, 'add_meta_boxes' );

		// Action to save meta information on post save.
		$this->loader->add_action( 'save_post', $this->plugin_admin, 'save_post_meta_fields' );
		$this->loader->add_action( 'new_to_publish', $this->plugin_admin, 'save_post_meta_fields' );
		$this->loader->add_action( 'admin_menu', $this->plugin_admin, 'remove_custom_post_type_submenu' );
		$this->loader->add_action( 'admin_enqueue_scripts', $this->plugin_admin, 'remove_add_new_button' );
		$this->loader->add_action( 'admin_notices', $this->plugin_admin, 'add_notification_to_admin_page' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 */
	private function define_public_hooks() {

		$this->loader->add_action( 'wp_enqueue_scripts', $this->plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $this->plugin_public, 'enqueue_scripts' );

		// Plugin init operations.
		$this->loader->add_action( 'init', $this, 'plugin_init' );

		// Ajax hook to get album by user code.
		$this->loader->add_action( 'wp_ajax_get_album_by_user_code', $this->plugin_public, 'get_album_by_user_code' );
		$this->loader->add_action( 'wp_ajax_nopriv_get_album_by_user_code', $this->plugin_public, 'get_album_by_user_code' );

		// Ajax hook to save selected images.
		$this->loader->add_action( 'wp_ajax_save_selections', $this->plugin_public, 'save_selected_images' );
		$this->loader->add_action( 'wp_ajax_nopriv_save_selections', $this->plugin_public, 'save_selected_images' );

		// Add custom data with the cart item data.
		$this->loader->add_filter( 'woocommerce_add_cart_item_data', $this->plugin_public, 'add_custom_data_to_cart_item', 10, 4 );

		// Add data to cart object.
		$this->loader->add_action( 'woocommerce_get_cart_item_from_session', $this->plugin_public, 'add_custom_data_to_cart_object', 10, 3 );

		// Add custom data to order meta data.
		$this->loader->add_action( 'woocommerce_checkout_create_order_line_item', $this->plugin_public, 'add_custom_data_to_wc_order_item_meta', 20, 4 );

		// Show selected images in cart.
		$this->loader->add_filter( 'woocommerce_cart_item_name', $this->plugin_public, 'show_selected_images_in_cart', 10, 3 );

		// Hook to add custom links after order items in admin.
		$this->loader->add_action( 'woocommerce_after_order_itemmeta', $this->plugin_public, 'show_custom_link_after_order_item_admin', 20, 3 );

		// Add the selected images in order received page.
		$this->loader->add_action( 'woocommerce_order_item_meta_start', $this->plugin_public, 'add_images_in_order_received_page', 10, 4 );

		// Add selected images in the order received email.
		$this->loader->add_action( 'woocommerce_email_order_meta', $this->plugin_public, 'show_selected_images_in_order_email', 10, 3 );

		$this->loader->add_action( 'woocommerce_after_order_details', $this->plugin_public, 'show_digital_products_download_on_view_order', 10, 3 );

		$this->loader->add_action( 'woocommerce_before_account_downloads', $this->plugin_public, 'show_message_before_downloads', 10, 3 );

		// Update choosen images on cart update.
		$this->loader->add_filter( 'woocommerce_update_cart_action_cart_updated', $this->plugin_public, 'remove_selected_images_on_qty_decrease', 10, 3 );

	}

	/**
	 * Register all of the shortcodes provided by the plugin.
	 *
	 * @since    1.0.0
	 */
	private function define_shortcodes() {

		// Create client album shortcode.
		$this->loader->add_shortcode(
			CSP_PLUGIN_PREFIX . '_client_album',
			$this->plugin_public,
			'show_client_album'
		);

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * Runs on init hook of the plugin.
	 *
	 * @since    1.0.0
	 */
	public function plugin_init() {

		// Register post types.
		$this->plugin_admin->register_cpts();

		// Register new image size.
		$this->plugin_admin->register_image_size();

	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Wp_Csp_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
