<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://dreamstyle.photos
 * @since      1.0.0
 *
 * @package    Wp_csp
 * @subpackage Wp_csp/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wp_csp
 * @subpackage Wp_csp/public
 */
class Wp_Csp_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Csp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Csp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// For jquery modal.
		wp_register_style( CSP_PLUGIN_PREFIX . '-jquery-modal', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-modal/0.9.1/jquery.modal.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( CSP_PLUGIN_PREFIX . '-jquery-modal' );

		// For Bootstrap.
		wp_register_style( CSP_PLUGIN_PREFIX . '-bootstrap', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( CSP_PLUGIN_PREFIX . '-bootstrap' );

		// For Bootstrap.
		wp_register_style( CSP_PLUGIN_PREFIX . '-lightbox', 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap-lightbox/0.7.0/bootstrap-lightbox.min.css', array( CSP_PLUGIN_PREFIX . '-bootstrap' ), $this->version, 'all' );
		wp_enqueue_style( CSP_PLUGIN_PREFIX . '-lightbox' );

		wp_register_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wp_csp-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Csp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Csp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// For Jquery modal.
		wp_register_script( CSP_PLUGIN_PREFIX . '-jquery-modal', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-modal/0.9.1/jquery.modal.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( CSP_PLUGIN_PREFIX . '-jquery-modal' );

		// For Bootstrap.
		wp_register_script( CSP_PLUGIN_PREFIX . '-bootstrap', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array(), $this->version, true );
		wp_enqueue_script( CSP_PLUGIN_PREFIX . '-bootstrap' );

		// For lightbox gallery.
		wp_register_script( CSP_PLUGIN_PREFIX . '-lightbox', 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap-lightbox/0.7.0/bootstrap-lightbox.min.js', array( CSP_PLUGIN_PREFIX . '-bootstrap' ), $this->version, true );
		wp_enqueue_script( CSP_PLUGIN_PREFIX . '-lightbox' );

		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wp_csp-public.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name );
		wp_localize_script( $this->plugin_name, CSP_PLUGIN_PREFIX . '_ajax_url', array( admin_url( 'admin-ajax.php' ) ) );

		$translation_array = array(
			'changeSelection' => __( 'Change selection', 'wp_csp' ),
			'selectPhotos'    => __( 'Please select photos', 'wp_csp' ),
			'selectExactly'   => __( 'Please select exactly ', 'wp_csp' ),
			'anyNumber'       => __( 'any number of', 'wp_csp' ),
			'validCode'       => __( 'Please enter a valid User-Code', 'wp_csp' ),
			'select'          => __( 'Select', 'wp_csp' ),
			'please_wait'     => __( 'Please wait...', 'wp_csp' ),
		);
		wp_localize_script( $this->plugin_name, CSP_PLUGIN_PREFIX . '_langvars', $translation_array );

	}

	/**
	 * Shortcode callback to get the secret code.
	 *
	 * @since    1.0.0
	 */
	public function show_client_album() {

		$html = '<p>
                    <div id="' . CSP_PLUGIN_PREFIX . '_selected_images_container"></div><br><br>
                    <label id="' . CSP_PLUGIN_PREFIX . '_user_code_label">' . __( 'Please type in your User-Code', 'wp_csp' ) . '</label>
                    <br>
                    <br>
                    <input type="text" name="' . CSP_PLUGIN_PREFIX . '_secret_code" id="' . CSP_PLUGIN_PREFIX . '_secret_code_text" class="csp_public_input" />
                    <input type="hidden" name="' . CSP_ALBUM_SECRET_CODE_NONCE_FIELD . '"
                    id="' . CSP_ALBUM_SECRET_CODE_NONCE_FIELD . '" value="' . wp_create_nonce( CSP_ALBUM_SECRET_CODE_NONCE_KEY ) . '">
                    <br>
                    <span id="' . CSP_PLUGIN_PREFIX . '_error_msg_container" style="color: red;"></span>
                    <br>
                    <button id="' . CSP_PLUGIN_PREFIX . '_secret_code_button" class="csp_public_button">' . __( 'Start', 'wp_csp' ) . '</button>
                </p>
                <!-- Modal -->
                <div id="' . CSP_PLUGIN_PREFIX . '_image_selection_modal" class="csp_public_popup modal">
                                        
                    <div>' . __( 'Please select', 'wp_csp' ) . ' <span id="' . CSP_PLUGIN_PREFIX . '_no_of_image_to_select_label" class="' . CSP_PLUGIN_PREFIX . '_public_bignumber"></span> ' . __( 'photos', 'wp_csp' ) . '</div>
                    
                    <span id="' . CSP_PLUGIN_PREFIX . '_modal_error_msg_container" style="color: red;"></span>
                    
                    <form id="' . CSP_PLUGIN_PREFIX . '_public_image_selection_form" name="' . CSP_PLUGIN_PREFIX . '_public_image_selection_form">
                        <div id="' . CSP_PLUGIN_PREFIX . '_public_image_gallery_wrapper">
                        </div>

                        <div class="' . CSP_PLUGIN_PREFIX . '_public_hinttext"><strong id="csp_public_album_info_hl">' . __( 'Album information', 'wp_csp' ) . ':</strong>
                            <p id="' . CSP_PLUGIN_PREFIX . '_public_album_hint_text"></p>
                        </div>
                        
                        <input type="hidden" id="' . CSP_PLUGIN_PREFIX . '_public_no_of_images_to_select_text" name="' . CSP_PLUGIN_PREFIX . '_public_no_of_images_to_select_text">
                        <input type="hidden" id="' . CSP_PLUGIN_PREFIX . '_save_selections_nonce" name="' . CSP_PLUGIN_PREFIX . '_save_selections_nonce" value="' . wp_create_nonce( CSP_SAVE_SELECTION_NONCE_KEY ) . '">
                        
                        <button type="submit" class="' . CSP_PLUGIN_PREFIX . '_public_button csp_public_center">' . __( 'Select', 'wp_csp' ) . '</button>
                    </form>
                    <a href="#close-modal" rel="modal:close" class="close-modal ">' . __( 'Close', 'wp_csp' ) . '</a>

                </div>
				<script>jQuery("#csp_image_selection_modal").appendTo("body");</script>
				';

		return $html;

	}

	/**
	 * Gets album by user code.
	 *
	 * @since    1.0.0
	 */
	public function get_album_by_user_code() {

		$msg     = 'Invalid Request';
		$success = 0;
		$data    = array();

		// Validate nonce and secret code.
		if ( ! empty( $_POST['secretCode'] ) && isset( $_POST['nonce'] ) && wp_verify_nonce( sanitize_key( $_POST['nonce'] ), CSP_ALBUM_SECRET_CODE_NONCE_KEY ) ) {

			// Run wp meta query.
			$args = array(
				'numberposts' => 1,
				'post_type'   => CSP_CPT_NAME,
				'meta_query'  => array(
					array(
						'key'     => CSP_ALBUM_SECRET_CODE_META_KEY,
						'value'   => sanitize_key( $_POST['secretCode'] ),
						'compare' => 'IN',
					),
				),
			);

			$query = new WP_Query( $args );

			// Check if post is found.
			if ( empty( $query->post ) ) {
				$msg = __( 'Invalid user code', 'wp_csp' );
			} else {

				$msg     = 'Success';
				$success = 1;

				// Send the data.
				$data['id'] = $query->post->ID;

				// Get no of images to select and hint text.
				$data['no_of_image_to_select'] = (int) maybe_unserialize( get_post_meta( $query->post->ID, CSP_NO_OF_IMAGE_TO_SELECT_META_KEY, true ) );
				$data['hint_text']             = maybe_unserialize( get_post_meta( $query->post->ID, CSP_ALBUM_HINT_TEXT, true ) );
				$data['is_pricing_per_album']  = (int) maybe_unserialize( get_post_meta( $query->post->ID, CSP_PRICING_PER_ALBUM_META_KEY, true ) );
				// Get the album images.
				$original_imgs = maybe_unserialize( get_post_meta( $query->post->ID, CSP_ALBUM_IMAGES_META_KEY_RENAMED, true ) );

				$images = array();
				if ( $original_imgs ) {
					foreach ( $original_imgs as $key => $val ) {
						$images [ $key ] = CSP_ALBUM_IMG_BASE_URL . '/' . $val;
					}
				}

				$data['images'] = $images;

			}
		}

		// Echo response.
		echo wp_json_encode(
			array(
				'message' => $msg,
				'success' => $success,
				'data'    => $data,
			)
		);
		exit;

	}

	/**
	 * Save selections.
	 *
	 * @since    1.0.0
	 */
	public function save_selected_images() {

		$msg     = 'Invalid Request';
		$success = 0;
		// Validate nonce and secret code.
		if ( ! empty( $_POST['selectedImages'] ) && isset( $_POST['is_pricing_per_album'] ) && isset( $_POST['nonce'] ) && wp_verify_nonce( sanitize_key( $_POST['nonce'] ), CSP_SAVE_SELECTION_NONCE_KEY ) ) {

			session_start();
			$post = $_POST;
			// Set the selected image urls in session.
			$_SESSION[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] = $post['selectedImages'];
			$_SESSION[ CSP_PRICING_PER_ALBUM_SESSION_KEY ]   = ( 0 == $post['is_pricing_per_album'] ) ? 'no' : 'yes';

			$msg     = 'Success';
			$success = 1;

		}
		// Echo response.
		echo wp_json_encode(
			array(
				'message' => $msg,
				'success' => $success,
			)
		);
		exit;

	}

	/**
	 * Adds custom data to cart item on adding product to the cart.
	 *
	 * @since   1.0.0
	 *
	 * @param   array $cart_item_data           Cart item datas.
	 * @param   int   $product_id               Current product ID.
	 * @param   int   $variation_id             Current variation ID.
	 * @param   int   $quantity                 Current quantity of item.
	 *
	 * @return  array                           New cart item datas.
	 */
	public function add_custom_data_to_cart_item( $cart_item_data, $product_id, $variation_id, $quantity ) {

		session_start();
		// If present in session.
		if ( ! empty( $_SESSION[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] ) ) {

			$total_imgs = count( $_SESSION[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] );

			if ( $quantity < $total_imgs && 'no' == $_SESSION[ CSP_PRICING_PER_ALBUM_SESSION_KEY ] ) {
				$new_img_arr = array_slice( $_SESSION[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ], 0, ( $quantity - $total_imgs ), true );

				$cart_item_data[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] = $new_img_arr;
			} else {
				$cart_item_data[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] = $_SESSION[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ];
			}

			$cart_item_data[ CSP_PRICING_PER_ALBUM_SESSION_KEY ] = $_SESSION[ CSP_PRICING_PER_ALBUM_SESSION_KEY ];
		}

		return $cart_item_data;

	}

	/**
	 * Adds custom data to woocommerce cart object from cart item data.
	 *
	 * @since   1.0.0
	 *
	 * @param   array $item                     Cart item object.
	 * @param   array $values                   Existing values.
	 * @param   array $key                      Existing keys.
	 *
	 * @return  array                           New cart item datas.
	 */
	public function add_custom_data_to_cart_object( $item, $values, $key ) {

		// If Selected image urls exists.
		if ( array_key_exists( CSP_SELECTED_IMAGE_URLS_SESSION_KEY, $values ) ) {
			$item[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] = $values[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ];
		}

		return $item;

	}

	/**
	 * Adds custom data to woocommerce order meta.
	 *
	 * @since   1.0.0
	 *
	 * @param   object $item                  Cart item object.
	 * @param   string $cart_item_key            Unique encoded ID of cart items.
	 * @param   array  $values                  Existing values.
	 * @param   object $order                Woo order object.
	 */
	public function add_custom_data_to_wc_order_item_meta( $item, $cart_item_key, $values, $order ) {
		global $wpdb;

		// If selected image url is not empty.
		if ( array_key_exists( CSP_SELECTED_IMAGE_URLS_SESSION_KEY, $values ) ) {
			$selected_images = $values[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ];
			$item->update_meta_data( CSP_SELECTED_IMAGE_URLS_SESSION_KEY, $selected_images );
		}

	}

	/**
	 * Show selected images in cart.
	 *
	 * @since   1.0.0
	 *
	 * @param   string $title                  Cart item titles.
	 * @param   object $cart_item             Cart items.
	 * @param   string $cart_item_key          Unique encoded ID of cart items.
	 */
	public function show_selected_images_in_cart( $title, $cart_item, $cart_item_key ) {
		$images = '';
		if ( isset( $cart_item[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] ) ) {
			$images = '<dl>';

			// Loop through all the image urls.
			foreach ( $cart_item[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] as $id => $url ) {
				$images .= '<dt><img height="150" width="150" class="' . CSP_PLUGIN_PREFIX . '_images_in_cart" src="' . $url . '"></dt>';
			}

			$images .= '</dl>';
		}

		return $images;
	}

	/**
	 * Show custom link after order item meta admin
	 *
	 * @since   1.0.0
	 *
	 * @param   int    $item_id                 Item Id.
	 * @param   object $item                    Cart items.
	 * @param   object $product                 Woo product object.
	 */
	public function show_custom_link_after_order_item_admin( $item_id, $item, $product ) {

		// Only for "line item" order items.
		if ( ! $item->is_type( 'line_item' ) ) {
			return;
		}

		// Show the images selected.
		if ( is_admin() ) {

			$images = '';

			// Loop through all the image urls.
			if ( is_array( wc_get_order_item_meta( $item_id, CSP_SELECTED_IMAGE_URLS_SESSION_KEY ) ) ) {
				foreach ( wc_get_order_item_meta( $item_id, CSP_SELECTED_IMAGE_URLS_SESSION_KEY ) as $id => $url ) {
					$images .= '<a href="' . admin_url() . 'upload.php?item=' . $id . '">
									<img class="' . CSP_PLUGIN_PREFIX . '_images_in_cart" src="' . wp_get_attachment_image_src( $id, array( 100, 100 ), true )[0] . '">
								</a>';
				}
			}

			$arr = array(
				'a'   => array(
					'href' => array(),
				),
				'img' => array(
					'class' => array(),
					'src'   => array(),
				),
			);
			echo wp_kses( $images, $arr );

		}

	}

	/**
	 * Show images in order received page and mail.
	 *
	 * @since   1.0.0
	 *
	 * @param   int    $item_id                 Item Id.
	 * @param   object $item                    Cart items.
	 * @param   object $order                   Woo order object.
	 * @param   string $plain_text           contain text.
	 */
	public function add_images_in_order_received_page( $item_id, $item, $order, $plain_text ) {
		$images            = '';
		$product_image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $item->get_product_id() ), 'thumbnail' );
		if ( is_array( $product_image_url ) ) {
			$product_image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $item->get_product_id() ), 'thumbnail' )[0];
		}
		$images = '<div><div class="wc-order-item-thumbnail"><img width="100" height="100" src="' . $product_image_url . '" class="attachment-thumbnail size-thumbnail" alt="" loading="lazy" title=""></div>';

		$product = wc_get_product( $item->get_product_id() );
		// Loop through all the image urls.
		if ( is_array( wc_get_order_item_meta( $item_id, CSP_SELECTED_IMAGE_URLS_SESSION_KEY ) ) ) {
			foreach ( wc_get_order_item_meta( $item_id, CSP_SELECTED_IMAGE_URLS_SESSION_KEY ) as $id => $url ) {
				if ( $product->is_downloadable() && isset( $order ) && $order->has_status( 'completed' ) ) {
					$actual_image = wp_get_attachment_image_src( $id, 'large', true )[0];
					$images      .= '<a href="' . $actual_image . '" download><img src="' . $url . '" style="width: 60px;display: inline-block;margin: 2px;"></a>';
				} else {
					$image_title = get_the_title( $id );
					$images     .= '<img title="' . $image_title . '" src="' . $url . '" style="width: 60px;display: inline-block;margin: 2px;">';
				}
			}
		}

		$images = $images . '</div>';
		$arr    = array(
			'a'   => array(
				'href' => array(),
			),
			'img' => array(
				'class' => array(),
				'src'   => array(),
				'style' => array(),
				'title' => array(),
			),
		);
		echo wp_kses( $images, $arr );
	}


	/**
	 * Show images in the order received email
	 *
	 * @since   1.0.0
	 *
	 * @param   object $order                   Woo order object.
	 * @param   bool   $sent_to_admin          check if images to be sent to admin.
	 * @param   string $plain_text           contain text.
	 */
	public function show_selected_images_in_order_email( $order, $sent_to_admin, $plain_text ) {
		$html               = '';
		$is_any_other_image = false;
		$items              = $order->get_items();
		$links              = '<ul>';
		foreach ( $items as $item_id => $item ) {
			$selected_images = wc_get_order_item_meta( $item_id, CSP_SELECTED_IMAGE_URLS_SESSION_KEY );
			if ( $selected_images ) {
				$is_any_other_image = true;
				foreach ( $selected_images as $id => $url ) {
					$actual_src  = wp_get_attachment_image_src( $id, 'large', true )[0];
					$image_title = get_the_title( $id );
					if ( $sent_to_admin ) {
						$links .= '<li>' . $image_title . '</li>';
					} else {
						$product = wc_get_product( $item->get_product_id() );
						if ( $product->is_downloadable() && isset( $order ) && $order->has_status( 'completed' ) ) {
							$links .= '<li><a href="' . $actual_src . '" download">' . $image_title . '</a></li>';
						} else {
							$links .= '<li>' . $image_title . '</li>';
						}
					}
				}
			}
		}
		$links = $links . '</ul>';
		if ( $is_any_other_image ) {
			$html = '<h2>' . __( 'Your images', 'wp_csp' ) . "</h2> $links";
		}
		$arr = array(
			'a'  => array(
				'href' => array(),
			),
			'ul' => array(),
			'li' => array(),
			'h2' => array(),
		);
		echo wp_kses( $html, $arr );
	}

	/**
	 * Show images in the order view page my account
	 *
	 * @since   1.0.0
	 *
	 * @param   object $order                   Woo order object.
	 */
	public function show_digital_products_download_on_view_order( $order ) {
		$section            = '';
		$is_any_other_image = false;
		$items              = $order->get_items();
		$links              = '<ul>';
		foreach ( $items as $item_id => $item ) {
			$selected_images = wc_get_order_item_meta( $item_id, CSP_SELECTED_IMAGE_URLS_SESSION_KEY );
			if ( $selected_images ) {
				$is_any_other_image = true;
				foreach ( $selected_images as $id => $url ) {
					$actual_src  = wp_get_attachment_image_src( $id, 'large', true )[0];
					$image_title = get_the_title( $id );
					$product     = wc_get_product( $item->get_product_id() );
					if ( $product->is_downloadable() && isset( $order ) && $order->has_status( 'completed' ) ) {
						$links .= '<li><a href="' . $actual_src . '" download">' . $image_title . '</a></li>';
					} else {
						$links .= '<li>' . $image_title . '</li>';
					}
				}
			}
		}
		$links = $links . '</ul>';
		if ( $is_any_other_image ) {
			$section = "<section><h2 class='woocommerce-order-details__title'>" . __( 'Your images', 'wp_csp' ) . "</h2> $links</section>";
		}
		$arr = array(
			'a'       => array(
				'href' => array(),
			),
			'ul'      => array(),
			'li'      => array(),
			'section' => array(),
			'h2'      => array(
				'class' => array(),
			),
		);
		echo wp_kses( $section, $arr );
	}

	/**
	 * Show message before download
	 *
	 * @since   1.0.0
	 *
	 * @param   bool $has_downloads                 contains if downloadds present.
	 */
	public function show_message_before_downloads( $has_downloads ) {
		$orders_url    = wc_get_account_endpoint_url( 'orders' );
		$text          = __( 'Attention. If you have purchased digital photos. Please go to the', 'wp_csp' );
		$respect_order = __( 'respective order', 'wp_csp' );
		$download_text = __( 'here you can download the photos.', 'wp_csp' );

		$show_text = $text . ' <a href=' . $orders_url . '>' . $respect_order . '</a>, ' . $download_text;

		$show_text = '<span style="font-size: 14px;font-weight: 600;">' . $show_text . '</span><br><br>';
		$arr       = array(
			'a'    => array(
				'href' => array(),
			),
			'span' => array(
				'style' => array(),
			),
			'br'   => array(),
		);
		echo wp_kses( $show_text, $arr );
	}

	/**
	 * Remove selected images from cart
	 * If product qty decreased
	 *
	 * @param   boolean $cart_updated            true when cart is updated.
	 */
	public function remove_selected_images_on_qty_decrease( $cart_updated ) {
		$items       = WC()->cart->get_cart();
		$cart_update = false;

		foreach ( $items as $item => $values ) {
			$new_qty = $values['quantity'];
			if ( isset( $values[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] ) ) {
				$total_imgs  = count( $values[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] );
				$new_img_arr = array();

				if ( $new_qty < $total_imgs && 'no' == $values[ CSP_PRICING_PER_ALBUM_SESSION_KEY ] ) {
					$new_img_arr = array_slice( $values[ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ], 0, ( $new_qty - $total_imgs ), true );

					WC()->cart->cart_contents[ $item ][ CSP_SELECTED_IMAGE_URLS_SESSION_KEY ] = $new_img_arr;

					$cart_update = true;
				}
			}
		}
		if ( true == $cart_update ) {
			WC()->cart->set_session();
		}
		return $cart_updated;
	}
}
